@@ -628,7 +628,6 @@ class HasGeneratorProperties:
                              "The number of sequences to return from the beam search.",
                              typeConverter=TypeConverters.toInt)
 
-
     def setTask(self, value):
         """Sets the transformer's task, e.g. ``summarize:``.
 
@@ -639,7 +638,6 @@ class HasGeneratorProperties:
         """
         return self._set(task=value)
 
-
     def setMinOutputLength(self, value):
         """Sets minimum length of the sequence to be generated.
 
@@ -650,7 +648,6 @@ class HasGeneratorProperties:
         """
         return self._set(minOutputLength=value)
 
-
     def setMaxOutputLength(self, value):
         """Sets maximum length of output text.
 
@@ -661,7 +658,6 @@ class HasGeneratorProperties:
         """
         return self._set(maxOutputLength=value)
 
-
     def setDoSample(self, value):
         """Sets whether or not to use sampling, use greedy decoding otherwise.
 
@@ -672,7 +668,6 @@ class HasGeneratorProperties:
         """
         return self._set(doSample=value)
 
-
     def setTemperature(self, value):
         """Sets the value used to module the next token probabilities.
 
@@ -683,7 +678,6 @@ class HasGeneratorProperties:
         """
         return self._set(temperature=value)
 
-
     def setTopK(self, value):
         """Sets the number of highest probability vocabulary tokens to keep for
         top-k-filtering.
@@ -695,7 +689,6 @@ class HasGeneratorProperties:
         """
         return self._set(topK=value)
 
-
     def setTopP(self, value):
         """Sets the top cumulative probability for vocabulary tokens.
 
@@ -709,7 +702,6 @@ class HasGeneratorProperties:
         """
         return self._set(topP=value)
 
-
     def setRepetitionPenalty(self, value):
         """Sets the parameter for repetition penalty. 1.0 means no penalty.
 
@@ -725,7 +717,6 @@ class HasGeneratorProperties:
         """
         return self._set(repetitionPenalty=value)
 
-
     def setNoRepeatNgramSize(self, value):
         """Sets size of n-grams that can only occur once.
 
@@ -738,7 +729,6 @@ class HasGeneratorProperties:
         """
         return self._set(noRepeatNgramSize=value)
 
-
     def setBeamSize(self, value):
         """Sets the number of beam size for beam search.
 
@@ -749,7 +739,6 @@ class HasGeneratorProperties:
         """
         return self._set(beamSize=value)
 
-
     def setNReturnSequences(self, value):
         """Sets the number of sequences to return from the beam search.
 
@@ -765,14 +754,14 @@ class HasLlamaCppProperties:
     # -------- MODEl PARAMETERS --------
     nThreads = Param(Params._dummy(), "nThreads", "Set the number of threads to use during generation",
                      typeConverter=TypeConverters.toInt)
-    nThreadsDraft = Param(Params._dummy(), "nThreadsDraft", "Set the number of threads to use during draft generation",
-                          typeConverter=TypeConverters.toInt)
+    # nThreadsDraft = Param(Params._dummy(), "nThreadsDraft", "Set the number of threads to use during draft generation",
+    #                       typeConverter=TypeConverters.toInt)
     nThreadsBatch = Param(Params._dummy(), "nThreadsBatch",
                           "Set the number of threads to use during batch and prompt processing",
                           typeConverter=TypeConverters.toInt)
-    nThreadsBatchDraft = Param(Params._dummy(), "nThreadsBatchDraft",
-                               "Set the number of threads to use during batch and prompt processing",
-                               typeConverter=TypeConverters.toInt)
+    # nThreadsBatchDraft = Param(Params._dummy(), "nThreadsBatchDraft",
+    #                            "Set the number of threads to use during batch and prompt processing",
+    #                            typeConverter=TypeConverters.toInt)
     nCtx = Param(Params._dummy(), "nCtx", "Set the size of the prompt context", typeConverter=TypeConverters.toInt)
     nBatch = Param(Params._dummy(), "nBatch",
                    "Set the logical batch size for prompt processing (must be >=32 to use BLAS)",
@@ -782,12 +771,12 @@ class HasLlamaCppProperties:
                     typeConverter=TypeConverters.toInt)
     nDraft = Param(Params._dummy(), "nDraft", "Set the number of tokens to draft for speculative decoding",
                    typeConverter=TypeConverters.toInt)
-    nChunks = Param(Params._dummy(), "nChunks", "Set the maximal number of chunks to process",
-                    typeConverter=TypeConverters.toInt)
-    nSequences = Param(Params._dummy(), "nSequences", "Set the number of sequences to decode",
-                       typeConverter=TypeConverters.toInt)
-    pSplit = Param(Params._dummy(), "pSplit", "Set the speculative decoding split probability",
-                   typeConverter=TypeConverters.toFloat)
+    # nChunks = Param(Params._dummy(), "nChunks", "Set the maximal number of chunks to process",
+    #                 typeConverter=TypeConverters.toInt)
+    # nSequences = Param(Params._dummy(), "nSequences", "Set the number of sequences to decode",
+    #                    typeConverter=TypeConverters.toInt)
+    # pSplit = Param(Params._dummy(), "pSplit", "Set the speculative decoding split probability",
+    #                typeConverter=TypeConverters.toFloat)
     nGpuLayers = Param(Params._dummy(), "nGpuLayers", "Set the number of layers to store in VRAM (-1 - use default)",
                        typeConverter=TypeConverters.toInt)
     nGpuLayersDraft = Param(Params._dummy(), "nGpuLayersDraft",
@@ -802,10 +791,10 @@ class HasLlamaCppProperties:
                          typeConverter=TypeConverters.toString)
     mainGpu = Param(Params._dummy(), "mainGpu", "Set the main GPU that is used for scratch and small tensors.",
                     typeConverter=TypeConverters.toInt)
-    tensorSplit = Param(Params._dummy(), "tensorSplit", "Set how split tensors should be distributed across GPUs",
-                        typeConverter=TypeConverters.toListFloat)
-    grpAttnN = Param(Params._dummy(), "grpAttnN", "Set the group-attention factor", typeConverter=TypeConverters.toInt)
-    grpAttnW = Param(Params._dummy(), "grpAttnW", "Set the group-attention width", typeConverter=TypeConverters.toInt)
+    # tensorSplit = Param(Params._dummy(), "tensorSplit", "Set how split tensors should be distributed across GPUs",
+    #                     typeConverter=TypeConverters.toListFloat)
+    # grpAttnN = Param(Params._dummy(), "grpAttnN", "Set the group-attention factor", typeConverter=TypeConverters.toInt)
+    # grpAttnW = Param(Params._dummy(), "grpAttnW", "Set the group-attention width", typeConverter=TypeConverters.toInt)
     ropeFreqBase = Param(Params._dummy(), "ropeFreqBase", "Set the RoPE base frequency, used by NTK-aware scaling",
                          typeConverter=TypeConverters.toFloat)
     ropeFreqScale = Param(Params._dummy(), "ropeFreqScale",
@@ -837,7 +826,7 @@ class HasLlamaCppProperties:
                          typeConverter=TypeConverters.toString)
     # Set the RoPE frequency scaling method, defaults to linear unless specified by the model.
     #
-    #   - UNSPECIFIED: Don't use any scaling
+    #   - NONE: Don't use any scaling
     #   - LINEAR: Linear scaling
     #   - YARN: YaRN RoPE scaling
     ropeScalingType = Param(Params._dummy(), "ropeScalingType",
@@ -845,29 +834,30 @@ class HasLlamaCppProperties:
                             typeConverter=TypeConverters.toString)
     # Set the pooling type for embeddings, use model default if unspecified
     #
-    #   - 0 NONE: Don't use any pooling
-    #   - 1 MEAN: Mean Pooling
-    #   - 2 CLS: CLS Pooling
+    #   - MEAN: Mean Pooling
+    #   - CLS: CLS Pooling
+    #   - LAST: Last token pooling
+    #   - RANK: For reranked models
     poolingType = Param(Params._dummy(), "poolingType",
                         "Set the pooling type for embeddings, use model default if unspecified",
                         typeConverter=TypeConverters.toString)
     modelDraft = Param(Params._dummy(), "modelDraft", "Set the draft model for speculative decoding",
                        typeConverter=TypeConverters.toString)
     modelAlias = Param(Params._dummy(), "modelAlias", "Set a model alias", typeConverter=TypeConverters.toString)
-    lookupCacheStaticFilePath = Param(Params._dummy(), "lookupCacheStaticFilePath",
-                                      "Set path to static lookup cache to use for lookup decoding (not updated by generation)",
-                                      typeConverter=TypeConverters.toString)
-    lookupCacheDynamicFilePath = Param(Params._dummy(), "lookupCacheDynamicFilePath",
-                                       "Set path to dynamic lookup cache to use for lookup decoding (updated by generation)",
-                                       typeConverter=TypeConverters.toString)
+    # lookupCacheStaticFilePath = Param(Params._dummy(), "lookupCacheStaticFilePath",
+    #                                   "Set path to static lookup cache to use for lookup decoding (not updated by generation)",
+    #                                   typeConverter=TypeConverters.toString)
+    # lookupCacheDynamicFilePath = Param(Params._dummy(), "lookupCacheDynamicFilePath",
+    #                                    "Set path to dynamic lookup cache to use for lookup decoding (updated by generation)",
+    #                                    typeConverter=TypeConverters.toString)
     # loraAdapters = new StructFeature[Map[String, Float]](this, "loraAdapters")
     embedding = Param(Params._dummy(), "embedding", "Whether to load model with embedding support",
                       typeConverter=TypeConverters.toBoolean)
     flashAttention = Param(Params._dummy(), "flashAttention", "Whether to enable Flash Attention",
                            typeConverter=TypeConverters.toBoolean)
-    inputPrefixBos = Param(Params._dummy(), "inputPrefixBos",
-                           "Whether to add prefix BOS to user inputs, preceding the `--in-prefix` string",
-                           typeConverter=TypeConverters.toBoolean)
+    # inputPrefixBos = Param(Params._dummy(), "inputPrefixBos",
+    #                        "Whether to add prefix BOS to user inputs, preceding the `--in-prefix` string",
+    #                        typeConverter=TypeConverters.toBoolean)
     useMmap = Param(Params._dummy(), "useMmap",
                     "Whether to use memory-map model (faster load but may increase pageouts if not using mlock)",
                     typeConverter=TypeConverters.toBoolean)
@@ -880,6 +870,10 @@ class HasLlamaCppProperties:
                          typeConverter=TypeConverters.toString)
     chatTemplate = Param(Params._dummy(), "chatTemplate", "The chat template to use",
                          typeConverter=TypeConverters.toString)
+    logVerbosity = Param(Params._dummy(), "logVerbosity", "Set the log verbosity level",
+                         typeConverter=TypeConverters.toInt)
+    disableLog = Param(Params._dummy(), "disableLog", "Whether to disable logging",
+                       typeConverter=TypeConverters.toBoolean)
 
     # -------- INFERENCE PARAMETERS --------
     inputPrefix = Param(Params._dummy(), "inputPrefix", "Set the prompt to start generation with",
@@ -948,17 +942,17 @@ class HasLlamaCppProperties:
         """Set the number of threads to use during generation"""
         return self._set(nThreads=nThreads)
 
-    def setNThreadsDraft(self, nThreadsDraft: int):
-        """Set the number of threads to use during draft generation"""
-        return self._set(nThreadsDraft=nThreadsDraft)
+    # def setNThreadsDraft(self, nThreadsDraft: int):
+    #     """Set the number of threads to use during draft generation"""
+    #     return self._set(nThreadsDraft=nThreadsDraft)
 
     def setNThreadsBatch(self, nThreadsBatch: int):
         """Set the number of threads to use during batch and prompt processing"""
         return self._set(nThreadsBatch=nThreadsBatch)
 
-    def setNThreadsBatchDraft(self, nThreadsBatchDraft: int):
-        """Set the number of threads to use during batch and prompt processing"""
-        return self._set(nThreadsBatchDraft=nThreadsBatchDraft)
+    # def setNThreadsBatchDraft(self, nThreadsBatchDraft: int):
+    #     """Set the number of threads to use during batch and prompt processing"""
+    #     return self._set(nThreadsBatchDraft=nThreadsBatchDraft)
 
     def setNCtx(self, nCtx: int):
         """Set the size of the prompt context"""
@@ -976,17 +970,17 @@ class HasLlamaCppProperties:
         """Set the number of tokens to draft for speculative decoding"""
         return self._set(nDraft=nDraft)
 
-    def setNChunks(self, nChunks: int):
-        """Set the maximal number of chunks to process"""
-        return self._set(nChunks=nChunks)
+    # def setNChunks(self, nChunks: int):
+    #     """Set the maximal number of chunks to process"""
+    #     return self._set(nChunks=nChunks)
 
-    def setNSequences(self, nSequences: int):
-        """Set the number of sequences to decode"""
-        return self._set(nSequences=nSequences)
+    # def setNSequences(self, nSequences: int):
+    #     """Set the number of sequences to decode"""
+    #     return self._set(nSequences=nSequences)
 
-    def setPSplit(self, pSplit: float):
-        """Set the speculative decoding split probability"""
-        return self._set(pSplit=pSplit)
+    # def setPSplit(self, pSplit: float):
+    #     """Set the speculative decoding split probability"""
+    #     return self._set(pSplit=pSplit)
 
     def setNGpuLayers(self, nGpuLayers: int):
         """Set the number of layers to store in VRAM (-1 - use default)"""
@@ -1004,17 +998,17 @@ class HasLlamaCppProperties:
         """Set the main GPU that is used for scratch and small tensors."""
         return self._set(mainGpu=mainGpu)
 
-    def setTensorSplit(self, tensorSplit: List[float]):
-        """Set how split tensors should be distributed across GPUs"""
-        return self._set(tensorSplit=tensorSplit)
+    # def setTensorSplit(self, tensorSplit: List[float]):
+    #     """Set how split tensors should be distributed across GPUs"""
+    #     return self._set(tensorSplit=tensorSplit)
 
-    def setGrpAttnN(self, grpAttnN: int):
-        """Set the group-attention factor"""
-        return self._set(grpAttnN=grpAttnN)
+    # def setGrpAttnN(self, grpAttnN: int):
+    #     """Set the group-attention factor"""
+    #     return self._set(grpAttnN=grpAttnN)
 
-    def setGrpAttnW(self, grpAttnW: int):
-        """Set the group-attention width"""
-        return self._set(grpAttnW=grpAttnW)
+    # def setGrpAttnW(self, grpAttnW: int):
+    #     """Set the group-attention width"""
+    #     return self._set(grpAttnW=grpAttnW)
 
     def setRopeFreqBase(self, ropeFreqBase: float):
         """Set the RoPE base frequency, used by NTK-aware scaling"""
@@ -1049,7 +1043,16 @@ class HasLlamaCppProperties:
         return self._set(defragmentationThreshold=defragmentationThreshold)
 
     def setNumaStrategy(self, numaStrategy: str):
-        """Set optimization strategies that help on some NUMA systems (if available)"""
+        """Set optimization strategies that help on some NUMA systems (if available)
+
+        Possible values:
+
+        - DISABLED: No NUMA optimizations
+        - DISTRIBUTE: spread execution evenly over all
+        - ISOLATE: only spawn threads on CPUs on the node that execution started on
+        - NUMA_CTL: use the CPU map provided by numactl
+        - MIRROR: Mirrors the model across NUMA nodes
+        """
         numaUpper = numaStrategy.upper()
         numaStrategies = ["DISABLED", "DISTRIBUTE", "ISOLATE", "NUMA_CTL", "MIRROR"]
         if numaUpper not in numaStrategies:
@@ -1060,13 +1063,35 @@ class HasLlamaCppProperties:
         return self._set(numaStrategy=numaStrategy)
 
     def setRopeScalingType(self, ropeScalingType: str):
-        """Set the RoPE frequency scaling method, defaults to linear unless specified by the model"""
-        return self._set(ropeScalingType=ropeScalingType)
+        """Set the RoPE frequency scaling method, defaults to linear unless specified by the model.
+
+        Possible values:
+
+        - NONE: Don't use any scaling
+        - LINEAR: Linear scaling
+        - YARN: YaRN RoPE scaling
+        """
+        ropeScalingTypeUpper = ropeScalingType.upper()
+        ropeScalingTypes = ["NONE", "LINEAR", "YARN"]
+        if ropeScalingTypeUpper not in ropeScalingTypes:
+            raise ValueError(
+                f"Invalid RoPE scaling type: {ropeScalingType}. "
+                + f"Valid values are: {ropeScalingTypes}"
+            )
+        return self._set(ropeScalingType=ropeScalingTypeUpper)
 
     def setPoolingType(self, poolingType: str):
-        """Set the pooling type for embeddings, use model default if unspecified"""
+        """Set the pooling type for embeddings, use model default if unspecified
+
+        Possible values:
+
+        - MEAN: Mean Pooling
+        - CLS: CLS Pooling
+        - LAST: Last token pooling
+        - RANK: For reranked models
+        """
         poolingTypeUpper = poolingType.upper()
-        poolingTypes = ["NONE", "MEAN", "CLS", "LAST"]
+        poolingTypes = ["NONE", "MEAN", "CLS", "LAST", "RANK"]
         if poolingTypeUpper not in poolingTypes:
             raise ValueError(
                 f"Invalid pooling type: {poolingType}. "
@@ -1082,25 +1107,21 @@ class HasLlamaCppProperties:
         """Set a model alias"""
         return self._set(modelAlias=modelAlias)
 
-    def setLookupCacheStaticFilePath(self, lookupCacheStaticFilePath: str):
-        """Set path to static lookup cache to use for lookup decoding (not updated by generation)"""
-        return self._set(lookupCacheStaticFilePath=lookupCacheStaticFilePath)
+    # def setLookupCacheStaticFilePath(self, lookupCacheStaticFilePath: str):
+    #     """Set path to static lookup cache to use for lookup decoding (not updated by generation)"""
+    #     return self._set(lookupCacheStaticFilePath=lookupCacheStaticFilePath)
 
-    def setLookupCacheDynamicFilePath(self, lookupCacheDynamicFilePath: str):
-        """Set path to dynamic lookup cache to use for lookup decoding (updated by generation)"""
-        return self._set(lookupCacheDynamicFilePath=lookupCacheDynamicFilePath)
-
-    def setEmbedding(self, embedding: bool):
-        """Whether to load model with embedding support"""
-        return self._set(embedding=embedding)
+    # def setLookupCacheDynamicFilePath(self, lookupCacheDynamicFilePath: str):
+    #     """Set path to dynamic lookup cache to use for lookup decoding (updated by generation)"""
+    #     return self._set(lookupCacheDynamicFilePath=lookupCacheDynamicFilePath)
 
     def setFlashAttention(self, flashAttention: bool):
         """Whether to enable Flash Attention"""
         return self._set(flashAttention=flashAttention)
 
-    def setInputPrefixBos(self, inputPrefixBos: bool):
-        """Whether to add prefix BOS to user inputs, preceding the `--in-prefix` string"""
-        return self._set(inputPrefixBos=inputPrefixBos)
+    # def setInputPrefixBos(self, inputPrefixBos: bool):
+    #     """Whether to add prefix BOS to user inputs, preceding the `--in-prefix` string"""
+    #     return self._set(inputPrefixBos=inputPrefixBos)
 
     def setUseMmap(self, useMmap: bool):
         """Whether to use memory-map model (faster load but may increase pageouts if not using mlock)"""
@@ -1246,11 +1267,19 @@ class HasLlamaCppProperties:
     def setUseChatTemplate(self, useChatTemplate: bool):
         """Set whether generate should apply a chat template"""
         return self._set(useChatTemplate=useChatTemplate)
-    
+
     def setNParallel(self, nParallel: int):
         """Sets the number of parallel processes for decoding. This is an alias for `setBatchSize`."""
         return self.setBatchSize(nParallel)
 
+    def setLogVerbosity(self, logVerbosity: int):
+        """Set the log verbosity level"""
+        return self._set(logVerbosity=logVerbosity)
+
+    def setDisableLog(self, disableLog: bool):
+        """Whether to disable logging"""
+        return self._set(disableLog=disableLog)
+
     # -------- JAVA SETTERS --------
     def setTokenIdBias(self, tokenIdBias: Dict[int, float]):
         """Set token id bias"""
@@ -1260,9 +1289,9 @@ class HasLlamaCppProperties:
         """Set token id bias"""
         return self._call_java("setTokenBias", tokenBias)
 
-    def setLoraAdapters(self, loraAdapters: Dict[str, float]):
-        """Set LoRA adapters with their scaling factors"""
-        return self._call_java("setLoraAdapters", loraAdapters)
+    # def setLoraAdapters(self, loraAdapters: Dict[str, float]):
+    #     """Set LoRA adapters with their scaling factors"""
+    #     return self._call_java("setLoraAdapters", loraAdapters)
 
     def getMetadata(self):
         """Gets the metadata of the model"""
