@@ -257,6 +257,16 @@ class _E5Loader(ExtendedJavaWrapper):
         )
 
 
+class _MiniLMLoader(ExtendedJavaWrapper):
+    def __init__(self, path, jspark, use_openvino=False):
+        super(_MiniLMLoader, self).__init__(
+            "com.johnsnowlabs.nlp.embeddings.MiniLMEmbeddings.loadSavedModel",
+            path,
+            jspark,
+            use_openvino,
+        )
+
+
 class _BGELoader(ExtendedJavaWrapper):
     def __init__(self, path, jspark):
         super(_BGELoader, self).__init__(
@@ -1165,3 +1175,25 @@ class _Florence2TransformerLoader(ExtendedJavaWrapper):
             jspark,
             use_openvino,
         )
+class _E5VEmbeddingsLoader(ExtendedJavaWrapper):
+    def __init__(self, path, jspark, use_openvino=False):
+        super(_E5VEmbeddingsLoader, self).__init__(
+            "com.johnsnowlabs.nlp.embeddings.E5VEmbeddings.loadSavedModel",
+            path,
+            jspark,
+            use_openvino
+        )
+
+class _Phi4Loader(ExtendedJavaWrapper):
+    def __init__(self, path, jspark, use_openvino=False):
+        super(_Phi4Loader, self).__init__(
+            "com.johnsnowlabs.nlp.annotators.seq2seq.Phi4Transformer.loadSavedModel",
+            path,
+            jspark,
+            use_openvino,
+        )
+
+class _AutoGGUFRerankerLoader(ExtendedJavaWrapper):
+    def __init__(self, path, jspark):
+        super(_AutoGGUFRerankerLoader, self).__init__(
+            "com.johnsnowlabs.nlp.annotators.seq2seq.AutoGGUFReranker.loadSavedModel", path, jspark)
\ No newline at end of file
